habitat.views.habitat
=====================

.. automodule:: habitat.views.habitat

   
   
   .. rubric:: Functions

   .. autosummary::
   
      must_be_admin
      validate
      version
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      ForbiddenError
   
   